@@ -1,13 +1,11 @@
 import typer
 import yaml
 
-
 import json
 import logging
-import subprocess
 from enum import Enum
 from pathlib import Path
-from typing import Any, Dict, List
+from typing import Any, Dict
 
 
 class OutputTypeEnum(str, Enum):
@@ -16,13 +14,6 @@ class OutputTypeEnum(str, Enum):
     both = "BOTH"
 
 
-def install_apt_packages(dependencies: List[str]) -> None:
-    logging.info("Updating apt repository index")
-    subprocess.check_call(["apt", "update"])
-    logging.info("Installing apt dependencies")
-    subprocess.check_call(["apt", "install", "-y", " ".join(dependencies)])
-
-
 def write_json_openapi(openapi: Dict[str, Any], output_path: Path) -> None:
     logging.info(f"Writing OpenAPI to {str(output_path)}")
     with output_path.open("w") as f:
@@ -32,4 +23,4 @@ def write_json_openapi(openapi: Dict[str, Any], output_path: Path) -> None:
 def write_yaml_openapi(openapi: Dict[str, Any], output_path: Path) -> None:
     logging.info(f"Writing OpenAPI to {str(output_path)}")
     with output_path.open("w") as f:
-        yaml.dump(openapi, f)
\ No newline at end of file
+        yaml.dump(openapi, f)
